This contains examples from the `examples` directory in the catch2
distribution's v2.x branch.

Changes:

* Included the latest v2 `catch.hpp` header and compiled against that instead of
  `<catch2/catch.hpp>`
